==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/RangeSlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SliderBase } from "./SliderBase";
import { markType } from "igniteui-react-core";
import { RangeSliderValueEventArgs } from "./RangeSliderValueEventArgs";
/**
 * @hidden
 */
export let RangeSlider = /*@__PURE__*/ (() => {
    class RangeSlider extends SliderBase {
        constructor() {
            super(...arguments);
            this.input = null;
            this.change = null;
        }
        get aa() {
            let ret_ = this.e.m("lower");
            return ret_;
        }
        set aa(a) {
            let value_ = a;
            this.e.u("lower", value_);
        }
        get ab() {
            let ret_ = this.e.m("upper");
            return ret_;
        }
        set ab(a) {
            let value_ = a;
            this.e.u("upper", value_);
        }
        get ac() {
            let ret_ = this.e.m("ariaLabelLower");
            return ret_;
        }
        set ac(a) {
            let value_ = a;
            this.e.u("ariaLabelLower", value_);
        }
        get ad() {
            let ret_ = this.e.m("ariaLabelUpper");
            return ret_;
        }
        set ad(a) {
            let value_ = a;
            this.e.u("ariaLabelUpper", value_);
        }
        inputChanged() {
            if (this.input != null) {
                this.e.q("input", (a) => this.input(this, RangeSliderValueEventArgs.b(a)));
            }
            else {
                this.e.t("input");
            }
        }
        changeChanged() {
            if (this.change != null) {
                this.e.q("change", (a) => this.change(this, RangeSliderValueEventArgs.b(a)));
            }
            else {
                this.e.t("change");
            }
        }
    }
    RangeSlider.$t = /*@__PURE__*/ markType(RangeSlider, 'RangeSlider', SliderBase.$);
    return RangeSlider;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/RangeSlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SliderBase } from "./SliderBase";
import { markType } from "igniteui-react-core";
import { RangeSliderValueEventArgs } from "./RangeSliderValueEventArgs";
/**
 * @hidden
 */
export let RangeSlider = /*@__PURE__*/ (() => {
    class RangeSlider extends SliderBase {
        constructor() {
            super(...arguments);
            this.input = null;
            this.change = null;
        }
        get y() {
            let ret_ = this.e.n("lower");
            return ret_;
        }
        set y(a) {
            let value_ = a;
            this.e.v("lower", value_);
        }
        get z() {
            let ret_ = this.e.n("upper");
            return ret_;
        }
        set z(a) {
            let value_ = a;
            this.e.v("upper", value_);
        }
        get aa() {
            let ret_ = this.e.n("ariaLabelLower");
            return ret_;
        }
        set aa(a) {
            let value_ = a;
            this.e.v("ariaLabelLower", value_);
        }
        get ab() {
            let ret_ = this.e.n("ariaLabelUpper");
            return ret_;
        }
        set ab(a) {
            let value_ = a;
            this.e.v("ariaLabelUpper", value_);
        }
        inputChanged() {
            if (this.input != null) {
                this.e.r("input", (a) => this.input(this, RangeSliderValueEventArgs.b(a)));
            }
            else {
                this.e.u("input");
            }
        }
        changeChanged() {
            if (this.change != null) {
                this.e.r("change", (a) => this.change(this, RangeSliderValueEventArgs.b(a)));
            }
            else {
                this.e.u("change");
            }
        }
    }
    RangeSlider.$t = /*@__PURE__*/ markType(RangeSlider, 'RangeSlider', SliderBase.$);
    return RangeSlider;
})();
